.. archiving.rst
.. 
.. Project: AutoArchive
.. License: GNU GPLv3
.. 
.. Copyright (C) 2003 - 2012 Róbert Čerňanský



.. A section for the AutoArchive._archiving package.



AutoArchive._archiving
======================

.. automodule:: AutoArchive._archiving
   :no-members:



Sub-Packages
------------

.. toctree::
   :maxdepth: 1

   archiving.core



Modules
-------

iarchiving
^^^^^^^^^^

.. automodule:: AutoArchive._archiving.iarchiving



iarchiver
^^^^^^^^^

.. automodule:: AutoArchive._archiving.iarchiver
